@@ -99,7 +99,7 @@ dldoc <- function # Make directlabels documentation
         pngurls[f$name,p$name] <- pngfile
         if(!file.exists(pngfile)){
           cat(" ",f$name,sep="")
-          png(pngfile, type="cairo")
+          png(pngfile)
           set.seed(1)
           tryCatch({
             print(direct.label(p$plot,f$fun))
